@@ -1,8 +1,8 @@
-package MooseX::Getopt; # git description: v0.69-6-g6f5d9e0
+package MooseX::Getopt; # git description: v0.71-9-g9ad7b38
 # ABSTRACT: A Moose role for processing command line options
 # KEYWORDS: moose extension command line options attributes executable flags switches arguments
 
-our $VERSION = '0.70';
+our $VERSION = '0.72';
 
 use Moose::Role 0.56;
 use namespace::autoclean;
@@ -23,7 +23,7 @@ MooseX::Getopt - A Moose role for processing command line options
 
 =head1 VERSION
 
-version 0.70
+version 0.72
 
 =head1 SYNOPSIS
 
@@ -298,8 +298,18 @@ L<Getopt::Long::Descriptive> that you install.
 
 =head1 SEE ALSO
 
+=over 4
+
+=item *
+
 L<MooseX::Getopt::Usage>, an extension to generate man pages, with colour
 
+=item *
+
+L<MooX::Options>, similar functionality for L<Moo>
+
+=back
+
 =head1 SUPPORT
 
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Getopt>
@@ -317,7 +327,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Tomas Doran Stevan Little Yuval Kogman Florian Ragwitz Brandon L Black Shlomi Fish Hans Dieter Pearcey Olaf Alders Nelo Onyiah Ryan D Johnson Ricardo SIGNES Damien Krotkine Dave Rolsky Hinrik Örn Sigurðsson Ævar Arnfjörð Bjarmason Chris Prather Devin Austin Jose Luis Martinez Todd Hepler Dagfinn Ilmari Mannsåker Gordon Irving Gregory Oschwald Jesse Luehrs John Goulah Jonathan Swartz Justin Hunter Stuart A Johnston
+=for stopwords Karen Etheridge Tomas Doran Stevan Little Yuval Kogman Florian Ragwitz Brandon L Black Shlomi Fish Olaf Alders Hans Dieter Pearcey Ryan D Johnson Dave Rolsky Nelo Onyiah Ricardo SIGNES Ævar Arnfjörð Bjarmason Damien Krotkine Hinrik Örn Sigurðsson Jose Luis Martinez Gregory Oschwald Devin Austin Todd Hepler Chris Prather Jesse Luehrs Gordon Irving Drew Taylor Damyan Ivanov Stuart A Johnston Justin Hunter Jonathan Swartz John Goulah Dagfinn Ilmari Mannsåker
 
 =over 4
 
@@ -351,15 +361,11 @@ Shlomi Fish <shlomif@cpan.org>
 
 =item *
 
-Hans Dieter Pearcey <hdp@weftsoar.net>
-
-=item *
-
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
 
-Nelo Onyiah <nelo.onyiah@gmail.com>
+Hans Dieter Pearcey <hdp@weftsoar.net>
 
 =item *
 
@@ -367,19 +373,15 @@ Ryan D Johnson <ryan@innerfence.com>
 
 =item *
 
-Ricardo SIGNES <rjbs@cpan.org>
-
-=item *
-
-Damien Krotkine <dkrotkine@weborama.com>
-
-=item *
-
 Dave Rolsky <autarch@urth.org>
 
 =item *
 
-Hinrik Örn Sigurðsson <hinrik.sig@gmail.com>
+Nelo Onyiah <nelo.onyiah@gmail.com>
+
+=item *
+
+Ricardo SIGNES <rjbs@cpan.org>
 
 =item *
 
@@ -387,11 +389,11 @@ Hinrik Örn Sigurðsson <hinrik.sig@gmail.com>
 
 =item *
 
-Chris Prather <chris@prather.org>
+Damien Krotkine <dkrotkine@weborama.com>
 
 =item *
 
-Devin Austin <dhoss@cpan.org>
+Hinrik Örn Sigurðsson <hinrik.sig@gmail.com>
 
 =item *
 
@@ -399,19 +401,19 @@ Jose Luis Martinez <jlmartinez@capside.com>
 
 =item *
 
+Gregory Oschwald <goschwald@maxmind.com>
+
+=item *
+
+Devin Austin <dhoss@cpan.org>
+
+=item *
+
 Todd Hepler <thepler@employees.org>
 
 =item *
 
-Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
-
-=item *
-
-Gordon Irving <goraxe@goraxe.me.uk>
-
-=item *
-
-Gregory Oschwald <goschwald@maxmind.com>
+Chris Prather <chris@prather.org>
 
 =item *
 
@@ -419,15 +421,11 @@ Jesse Luehrs <doy@tozt.net>
 
 =item *
 
-John Goulah <jgoulah@cpan.org>
+Gordon Irving <goraxe@goraxe.me.uk>
 
 =item *
 
-Jonathan Swartz <swartz@pobox.com>
-
-=item *
-
-Justin Hunter <justin.d.hunter@gmail.com>
+Drew Taylor <drew@drewtaylor.com>
 
 =item *
 
@@ -435,8 +433,32 @@ Shlomi Fish <shlomif@shlomifish.org>
 
 =item *
 
+Stevan Little <stevan.little@gmail.com>
+
+=item *
+
+Damyan Ivanov <dmn@debian.org>
+
+=item *
+
 Stuart A Johnston <saj_git@thecommune.net>
 
+=item *
+
+Justin Hunter <justin.d.hunter@gmail.com>
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+John Goulah <jgoulah@cpan.org>
+
+=item *
+
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
